==> webkit2gtk_2.6.2+dfsg1.orig.tar.xz: webkit2gtk-2.6.2+dfsg1/Source/WebKit2/WebProcess/WebPage/gtk/PrinterListGtk.h <==
/*
 * Copyright (C) 2014 Igalia S.L.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef PrinterListGtk_h
#define PrinterListGtk_h

#if HAVE(GTK_UNIX_PRINTING)

#include <wtf/RefCounted.h>
#include <wtf/Vector.h>
#include <wtf/gobject/GRefPtr.h>

typedef struct _GtkPrinter GtkPrinter;

namespace WebKit {

class PrinterListGtk: public RefCounted<PrinterListGtk> {
public:
    static RefPtr<PrinterListGtk> shared();
    ~PrinterListGtk();

    GtkPrinter* findPrinter(const char*) const;
    GtkPrinter* defaultPrinter() const { return m_defaultPrinter; }

private:
    PrinterListGtk();

    static gboolean enumeratePrintersFunction(GtkPrinter*);
    void addPrinter(GtkPrinter*);

    Vector<GRefPtr<GtkPrinter>, 4> m_printerList;
    GtkPrinter* m_defaultPrinter;
    static PrinterListGtk* s_sharedPrinterList;
};

} // namespace WebKit

#endif // HAVE(GTK_UNIX_PRINTING)

#endif // WebPrintOperationGtk_h

==> webkit2gtk_2.8.5+dfsg1.orig.tar.xz: webkit2gtk-2.8.5+dfsg1/Source/WebKit2/WebProcess/WebPage/gtk/PrinterListGtk.h <==
/*
 * Copyright (C) 2014 Igalia S.L.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef PrinterListGtk_h
#define PrinterListGtk_h

#if HAVE(GTK_UNIX_PRINTING)

#include <wtf/RefCounted.h>
#include <wtf/Vector.h>
#include <wtf/gobject/GRefPtr.h>

typedef struct _GtkPrinter GtkPrinter;

namespace WebKit {

class PrinterListGtk: public RefCounted<PrinterListGtk> {
public:
    static RefPtr<PrinterListGtk> getOrCreate();
    ~PrinterListGtk();

    GtkPrinter* findPrinter(const char*) const;
    GtkPrinter* defaultPrinter() const { return m_defaultPrinter; }

private:
    PrinterListGtk();

    void addPrinter(GtkPrinter*);
    bool isEnumeratingPrinters() const { return m_enumeratingPrinters; }

    Vector<GRefPtr<GtkPrinter>, 4> m_printerList;
    GtkPrinter* m_defaultPrinter;
    bool m_enumeratingPrinters;
    static PrinterListGtk* s_sharedPrinterList;
};

} // namespace WebKit

#endif // HAVE(GTK_UNIX_PRINTING)

#endif // WebPrintOperationGtk_h
